summaryrefslogtreecommitdiff
path: root/examples
diff options
context:
space:
mode:
authorelie <elie>2013-09-23 12:46:25 +0000
committerelie <elie>2013-09-23 12:46:25 +0000
commit1717da979fdfdcdba3d46a5e21e1e4712bf67f06 (patch)
tree8be836af38e6adfc47581c532b647fa98960b66d /examples
parentb1f28b84cedbdea1ef26161bcd362dd895109fcc (diff)
downloadpysnmp-git-1717da979fdfdcdba3d46a5e21e1e4712bf67f06.tar.gz
query existing OID
Diffstat (limited to 'examples')
-rw-r--r--examples/v3arch/asyncore/manager/cmdgen/send-packets-from-specific-interface.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/examples/v3arch/asyncore/manager/cmdgen/send-packets-from-specific-interface.py b/examples/v3arch/asyncore/manager/cmdgen/send-packets-from-specific-interface.py
index 1c611a5b..fb167ba6 100644
--- a/examples/v3arch/asyncore/manager/cmdgen/send-packets-from-specific-interface.py
+++ b/examples/v3arch/asyncore/manager/cmdgen/send-packets-from-specific-interface.py
@@ -5,7 +5,7 @@
# with SNMPv2c, community 'public'
# over IPv4/UDP
# to an Agent at 195.218.195.228:161
# sending packets from primary local interface 0.0.0.0, local port 1024
# for two OIDs in tuple form
# stop on end-of-mib condition for both OIDs
#
@@ -39,7 +39,7 @@ config.addTargetParams(snmpEngine, 'my-creds', 'my-area', 'noAuthNoPriv', 0)
config.addTransport(
snmpEngine,
udp.domainName,
- udp.UdpSocketTransport().openClientMode(('0.0.0.0', 1024))
+ udp.UdpSocketTransport().openClientMode(('0.0.0.0', 61024))
)
config.addTargetAddr(
snmpEngine, 'my-router',
@@ -71,7 +71,7 @@ cmdgen.NextCommandGenerator().sendReq(
snmpEngine,
'my-router',
( ((1,3,6,1,2,1,1), None),
- ((1,3,6,1,4,1,1), None), ),
+ ((1,3,6,1,2,1,11), None), ),
cbFun
)
@@ -5,7 +5,7 @@
# over IPv4/UDP
# to an Agent at 195.218.195.228:161
-# sending packets from primary local interface 0.0.0.0, local port 1024
+# sending packets from primary local interface 0.0.0.0, local port 61024
# for two OIDs in tuple form
# stop on end-of-mib condition for both OIDs